/**
  *  \file client/dialogs/fleetopts.h
  *  \brief Fleet Cost Options dialog
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_DIALOGS_FLEETOPTS_H
#define PCC_V2_CLIENT_DIALOGS_FLEETOPTS_H

/** Options for fleet cost comparison. */
struct WFleetCostOptions {
    enum Fighters {
        ff_Free,                ///< Do not count fighters.
        ff_LFM,                 ///< Count fighters as ShipFighterCost.
        ff_Build,               ///< Count fighters as BaseFighterCost.
        ff_MAX
    };
    enum ShipTech {
        st_No,                  ///< Do not count ship tech.
        st_Player,              ///< Count ship tech once per player.
        st_Ship,                ///< Count ship tech once per ship.
        st_MAX
    };
    Fighters fighters;
    bool torps;                 ///< Include torpedo costs.
    bool engine;                ///< Include engine cost.
    bool planet;                ///< Include planet cost.
    bool base;                  ///< Include starbase cost.
    bool tech;                  ///< Include starbase tech level cost.
    ShipTech shiptech;
    bool team;                  ///< Display by team, not by player.
};

bool editFleetCostOptions(WFleetCostOptions& opts);

#endif
