/**
  *  \file client/tiles/planetgrowth.h
  *  \brief Planet Growth Tile
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_TILES_PLANETGROWTH_H
#define PCC_V2_CLIENT_TILES_PLANETGROWTH_H

#include "client/wtile.h"
#include "game/planet.h"
#include "game/planetpred.h"
#include "ui/widgets/button.h"

class GfxContext;

/** Planet growth tile. Displays growth on a planet. Unlike most other
    tiles which observe some object type, this takes a planet by
    copy, allowing to manipulate it. */
class WPlanetGrowthTile : public WTile {
 public:
    WPlanetGrowthTile(const GPlanet& planet);

    void setStructures(TPlanetaryStructure str, int n);
    void setNativeTax(int n);
    void setColonistTax(int n);
    void setEffectors(GPlanetEffectors eff);

    void drawData(GfxCanvas& can);
    bool handleEvent(const UIEvent& event, bool second_pass);

    Signal1<GPlanetEffectors> sig_effectorChange;

 private:
    void showItem(GfxContext& ctx, int x, int y, int32_t oldPop, int32_t newPop);
    void showExp(GfxContext& ctx, int x, int y, int32_t oldPop, int32_t newPop);

    GPlanet planet;
    GPlanetEffectors eff;
    UIButton btn_w;
    UIButton btn_r;
};

#endif
