/**
  *  \file tvcr.h
  *  \brief THost VCR class
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_TVCR_H
#define PCC_V2_TVCR_H

#include "game/vcr.h"

class VcrPlayerTHost : public VcrPlayer {
 public:
    enum {
        VCR_MAX_BEAMS = 10,
        VCR_MAX_TORPS = 10,
        VCR_MAX_FTRS  = 19      /* max # of tracks */
    };
    typedef int rand_type;
    typedef unsigned char rand_table_type;
 private:
    struct Status {
        uint8_t beam_status[VCR_MAX_BEAMS];
        uint8_t torp_status[VCR_MAX_TORPS];
        uint8_t ftr_active[VCR_MAX_FTRS];
        int16_t ftr_x[VCR_MAX_FTRS];
        int16_t cur_x;
        int16_t damage_limit;
        int16_t num_fighters_out;
        int side;
        GVcrObject obj;
        void clear();
    };
    struct StatusToken : public VcrStatus {
        Status status[2];
        int seed;
        int status_word;
        int nuflag;
        StatusToken(time_type t);
    };    
    
    int seed;
    int nuflag;
    Status status[2];

    inline rand_type psrandom_1_20();
    inline rand_type psrandom_1_100();
    inline rand_type psrandom_1_17();
    inline int32_t rdivadd(int32_t a, int32_t b, int32_t plus);
    
    inline bool isFreighter(const Status& st);

    void hit(Status& st, int damage, int kill);

    inline void launchFighter(Status& st);
    inline void launchFighters(Status& st);
    inline void fighterShoot(Status& st, Status& opp, int i);
    inline void killFighter(Status& st, int i);
    inline void fighterStuff();

    void rechargeBeams(Status& st);
    void fireBeam(Status& st, Status& opp, int which);
    void fireBeams(Status& st, Status& opp);
    void fireAtFighter(Status& st, Status& opp, int beam);
    void fireBeamsAtFighter(Status& st, Status& opp);

    inline void fireTorp(Status& st, Status& opp, int launcher);
    void fireTorpedoes(Status& st, Status& opp);

    void preloadWeapons(Status& st);

    static bool checkVcrSide(GClassicVcr& avcr, int side);
 public:
    VcrPlayerTHost(bool nuflag);

    bool checkVcr(GClassicVcr& avcr);
    void initVcr(const GClassicVcr& avcr);
    void doneVcr(GClassicVcr& avcr);
    bool setCapabilities(uint16 cap);

    bool playCycle();
    void playFastForward();

    int getBeamStatus(int side, int id);
    int getTorpStatus(int side, int id);
    int getTorpCount(int side);
    int getFighterCount(int side);
    int getShields(int side);
    int getDamage(int side);
    int getCrew(int side);
    int getFighterX(int side, int id);
    int getFighterStatus(int side, int id);
    int getObjectX(int side);
    long getDistance();

    VcrStatus* getStatusToken();
    void setStatus(VcrStatus& status);
};

#endif
