/**
  *  \file ui/widgets/listlikenumbersel.cc
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/listlikenumbersel.h"
#include "util/misc.h"
#include "ui/skin.h"
#include "gfx/palette.h"
#include "ui/uiglobal.h"

UIListLikeNumberSelector::UIListLikeNumberSelector(int id, string_t label, int min, int max, int step)
    : UIDecimalSelector(id, min, max, step),
      label(label)
{ }

UIListLikeNumberSelector::~UIListLikeNumberSelector()
{ }

void
UIListLikeNumberSelector::drawContent(GfxCanvas& can)
{
    string_t text_l = " " + label;
    string_t text_r = numToString(getValue()) + " ";
    const UIColorSet& scheme = (getFocusState() != NoFocus ? BLACK_COLOR_SET : GRAY_COLOR_SET);

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(GfxStandardColorScheme::instance);
    ctx.useFont(*fonts[FONT_NORMAL]);

    // Background
    drawSolidBar(ctx, extent, scheme[UIColor::tc_Background]);

    // length
    int len   = fonts[FONT_NORMAL]->getTextWidth(text_r);
    int split = extent.w - len;

    // draw right side first
    ctx.setColor(scheme[UIColor::tc_Static]);
    outTextF(ctx, extent.x + split, extent.y, len, text_r);
    outTextF(ctx, extent.x, extent.y, split, text_l);

    can.update(extent);
}

void
UIListLikeNumberSelector::getLayoutInfo(LayoutInfo& info)
{
    info.min_size = info.pref_size =
        GfxPoint(fonts[FONT_NORMAL]->getTextWidth(label + "  99999"),
                 font_heights[FONT_NORMAL]);
    info.flags = li_FlexibleH;
}
