/**
  *  \file ui/widgets/radiobutton.h
  *  \brief UIRadioButton widget
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_RADIOBUTTON_H
#define PCC_V2_UI_WIDGETS_RADIOBUTTON_H

#include "ui/widgets/abstractcheckbox.h"
#include "cpluslib/sigslot.h"

/** \class UIRadioButton
    \brief Radio button

    From all radio buttons in a group, only one may be checked at a time.
    The actual value of a radio button group is stored in an object of
    type UIRadioButton::Value. */

class UIRadioButton : public UIAbstractCheckbox {
 public:
    typedef Observable<int> Value;
 private:
    Value& value;
    int myvalue;
    SignalConnection conn;

    void click(int);
 public:
    UIRadioButton(int id, string_t name, UIKey key, Value& valuep, int myvalue);
    ~UIRadioButton();

    void          setValue(int newvalue) { value.set(newvalue); }
    int           getValue() const { return value.get(); }
    Signal1<int>& getSignal() const { return value.sig_changed; }

    Ptr<GfxPixmap> getPixmap();
};

#endif
